pub enum NodeProps {
EffectNode(EffectNodeProps),
ScreenOutputNode(ScreenOutputNodeProps),
UiBgNode(UiBgNodeProps),
ImageNode(ImageNodeProps),
PlaceholderNode(PlaceholderNodeProps),
MovieNode(MovieNodeProps),
ProjectionMappedOutputNode(ProjectionMappedOutputNodeProps),
}Expand description
NodeProps govern the construction and behavior of a single node.
For example, an EffectNode has properties of name and intensity.
Some, but not all fields in NodeProps can be edited live.
For instance, editing an EffectNode’s intensity every frame
is supported, but editing its name between successive paint calls
will likely cause the EffectNode to enter an error state.
To change an EffectNode’s name, it must be re-added with a new ID.
NodeProps enumerates all possible node types,
and delegates to their specific props struct,
e.g. EffectNodeProps.
Variants
EffectNode(EffectNodeProps)
ScreenOutputNode(ScreenOutputNodeProps)
UiBgNode(UiBgNodeProps)
ImageNode(ImageNodeProps)
PlaceholderNode(PlaceholderNodeProps)
MovieNode(MovieNodeProps)
ProjectionMappedOutputNode(ProjectionMappedOutputNodeProps)