pub struct Props {
pub graph: Graph,
pub node_props: HashMap<NodeId, NodeProps>,
pub time: f32,
pub dt: f32,
pub audio: AudioLevels,
}Expand description
Props contains nodes (such as effects, movies, and images)
and connectivity information (which nodes feed into which other nodes)
that describe an overall visual composition.
Each node has properties, accessed via node_props,
describing that node’s behavior.
This Props object is a descriptor:
It does not contain any render state or graphics resources.
One use case of a Props is passing it to Context.paint for rendering.
Another is serializing it out to disk,
or deserializing it from a server.
Fields
graph: GraphThe list of node IDs and how they connect
node_props: HashMap<NodeId, NodeProps>Properties of each node, independent of connectivity
time: f32Time, in beats. Wraps around at 64 beats.
dt: f32Time between successive calls to update(), in beats
audio: AudioLevelsAudio levels
Implementations